@@ -143,7 +143,6 @@ class Queue(base.AMQPClass):
         # Set the value
         super(Queue, self).__setattr__(name, value)
 
-
     def bind(self, source, routing_key=None, arguments=None):
         """Bind the queue to the specified exchange or routing key.
 
@@ -275,7 +274,7 @@ class Queue(base.AMQPClass):
         if hasattr(source, 'name'):
             source = source.name
         routing_key = routing_key or self.name
-        self._rpc(specification.Queue.Bind(queue=self.name, exchange=source,
+        self._rpc(specification.Queue.Unbind(queue=self.name, exchange=source,
                                            routing_key=routing_key))
 
     def _declare(self, passive=False):
